.. highlight:: shell

============
インストール方法
============


安定版
--------------

deep_translatorをインストールしたい場合、以下のコマンドをターミナルで入力してください:

.. code-block:: console

    $ pip install deep_translator

常に最新の安定版をインストールできるため、deep_translatorはこの方法でインストールすることを推奨します。

pipがインストールされていない場合は、以下のPythonインストールガイドを参照してください。

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

deep_translatorのソースはGithubのリポジトリからダウンロードできます.

公開されているリポジトリのクローンも可能です:

.. code-block:: console

    $ git clone git://github.com/nidhaloff/deep_translator

tarballをインストールする場合は以下のようになります:

.. code-block:: console

    $ curl -OJL https://github.com/nidhaloff/deep_translator/tarball/master

クローンした後に、以下のコマンドを実行することでインストールが出来ます:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/nidhaloff/deep_translator
.. _tarball: https://github.com/nidhaloff/deep_translator/tarball/master
